{% extends "admin/base_site.html" %}
{% load i18n l10n %}

{% block content %}
<form action="" method="post" enctype="multipart/form-data">
	  {% csrf_token %}
    {{ form }}
		<input type="hidden" name="action" value="import_from_json" />
		<input type="hidden" name="_selected_action" value="0" /> <!-- ugly hack -->
    <input type="hidden" name="post" value="yes" />
    <input type="submit" value="{% trans "Submit" %}" />
</form>
{% endblock %}
